<?php
/**
 * @package		##package##
 * @subpackage	##subpackage##
 * @author		##author##
 * @copyright 	##copyright##
 * @license		##license##
 * @version		##version##
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

require_once __DIR__ . '/lessc.inc.php';

class ZenLessCompiler extends lessc
{
	private $inputPath;

	private $outputPath;

	private $variables;

	private $compressedMode;

	private $tmpPath;

	private $filesToCompile;

	public function __construct($params)
	{
		parent::__construct($params);

		$this->inputPath = $params->inputPath;
		$this->outputPath = $params->outputPath;
		$this->variables = $params->variables;
		$this->filesToCompile = $params->filesToCompile;
		$this->compressedMode = $params->compressedMode;
		$this->tmpPath = $params->tmpPath;
	}

	public function run()
	{
		jimport('joomla.filesystem.path');
		jimport('joomla.filesystem.file');
		jimport('joomla.filesystem.folder');

		$this->addImportDir(JPath::clean($this->inputPath));

		// Define compiler mode
		if ($this->compressedMode)
		{
			// Compile in Compressed mode
			$this->setFormatter("compressed");
		}
		else
		{
			// Preserving Comments on the output css file
			$this->setPreserveComments(false);

			// Compile in Classic mode
			$this->setFormatter("classic");
		}

		// The $variables var is injected by an included file
		if (isset($this->variables))
		{
			$this->setVariables($this->variables);
		}

		// if something goes wrong, it returns an error message.
		try
		{
			if (empty($this->tmpPath))
			{
				// Get a temporary folder to handle less files
				$settings = JFactory::getConfig();
				$this->tmpPath = $settings->get('tmp_path') . '/';

				$this->tmpPath = str_replace('/administrator/', '/', $this->tmpPath);
				$this->tmpPath = str_replace(JPATH_SITE, '', $this->tmpPath);
				$this->tmpPath = JPATH_SITE . '/' . $this->tmpPath . '/zenbridge-less/';
			}

			// Create if needed the temporary folder
			if (JFolder::exists($this->tmpPath))
			{
				JFolder::delete($this->tmpPath);
			}
			JFolder::create($this->tmpPath);


			// The input can be an array of .less files
			foreach ($this->filesToCompile as $output => $input)
			{
				if (!is_array($input))
				{
					$input = (array) $input;
				}

				$filesToMerge = array();
				foreach ($input as $file)
				{
					if (!empty($file))
					{
						// Compile the less file. The unique name is to avoid name conflict
						$tmpCSSFile = $this->tmpPath . '/' . md5($file . uniqid('ZEN', true)) . '.css';
						$filesToMerge[] = $tmpCSSFile;

						$this->compileFile($this->inputPath . '/' . $file, $tmpCSSFile);
					}
				}

				// Get the output full path
				$output = JPath::clean($this->outputPath . DIRECTORY_SEPARATOR . $output);

				// Merge/copy to one css file
				if (count($filesToMerge) > 1)
				{
					// Merge
					$buffer = '';
					foreach ($filesToMerge as $file)
					{
						$buffer .= JFile::read($file) . "\n";
					}

					// Output the merged file
					JFile::write($output, $buffer);
				}
				else
				{
					// Move the css file
					JFile::move($filesToMerge[0], $output);
				}
			}

			JFolder::delete($this->tmpPath);
		}
		catch (exception $e)
		{
			exit('LESS fatal error:<br />' . $e->getMessage());
		}
	}
}
