<?php
/**
 * @package		Zen Tools
 * @subpackage	Zen Tools
 * @author		Joomla Bamboo - design@joomlabamboo.com
 * @copyright 	Copyright (c) 2014 Copyright (C), Joomlabamboo. All Rights Reserved.. All rights reserved.
 * @license		Copyright Joomlabamboo 2014
 * @version		1.11.5
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

if (!defined('TEMPLATE')) {
	define( 'TEMPLATE', basename(dirname(__FILE__)));
}

if (!class_exists('Gallery')) {
	class Gallery
	{
		
	
		
		public static function removeBasePath($path)
			{
				$basePath = JPATH_SITE . '/';
		
				if (empty($basePath))
				{
					$basePath = dirname($_SERVER['SCRIPT_FILENAME']);
				}
		
				return str_replace($basePath, '', $path);
			}
		
		
		public static function getResizedImage($image, $width, $height, $option)
		{
			return self::removeBasePath(ZenToolsResizeImageHelper::getResizedImage($image, $width, $height, $option));
		}
		
		
		public static function handleRemoteImage($image)
			{
				jimport('joomla.filesystem.path');
				jimport('joomla.filesystem.file');
		
				// Check if it is a remote image
				if ((bool)preg_match('/^http/i', $image))
				{
					// Import libraries
					jimport('joomla.filesystem.folder');
		
					$ext = pathinfo($image, PATHINFO_EXTENSION);
		
					$cacheFolder = JPath::clean(JPATH_ROOT . '/media/zen-gallery/tmp/');
					$dest = $cacheFolder . 'remote-image-' . md5($image) . '.' . $ext;
		
					if (!JFolder::exists($cacheFolder))
					{
						JFolder::create($cacheFolder);
					}
		
					if (!JFile::exists($dest) || filesize($dest) === 0)
					{
						// Check if the allow_url_open is enabled
						if ((bool)ini_get('allow_url_fopen'))
						{
							file_put_contents($dest, file_get_contents($image));
						}
						// Check if cUrl is enabled
						else if (in_array('curl', get_loaded_extensions()))
						{
							$fp = fopen($dest, 'wb');
		
							$curl = curl_init($image);
							curl_setopt($curl, CURLOPT_HEADER, false);
		    				curl_setopt($curl, CURLOPT_BINARYTRANSFER, 1);
							curl_setopt($curl, CURLOPT_FILE, $fp);
							curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
							curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
							curl_exec($curl);
							curl_close($curl);
		
							fclose($fp);
						}
					}
		
					// Check if the cached file exists
					if (JFile::exists($dest))
					{
						$image = str_replace(JPATH_ROOT . DIRECTORY_SEPARATOR, '', $dest);
					}
				}
		
				return $image;
			}
		
		
		public static function get_gallery_images($gallery,$templateId) {
			$gallery = self::get_gallery_content($gallery,$templateId);
			
			if($gallery !==null) {
				$images = $gallery->images;
				return $images;
			}
			
			else {
				return null;
			}
			
		}
		
		
		
		public static function get_gallery_content($gallery,$templateId) {
			$gallery = str_replace(' ', '-', $gallery);
			$path =  JPATH_BASE.'/templates/'.TEMPLATE.'/galleries/'.$gallery.'_'. $templateId .'.json';
			
			if(file_exists($path)) {
				$gallery = file_get_contents($path);
				$content = json_decode($gallery);
				return $content;
			}
			else {
				return null;
			}
		}
		
		
		public static function get_layout_details($templateId) {
			
			$item_layout = JPATH_BASE.'/templates/'.TEMPLATE.'/settings/item-layout_' . $templateId .'.json';
			
			if (JFile::exists($item_layout)) {
				$layout = file_get_contents($item_layout);
			} else {
				$item_layout = JPATH_BASE.'/templates/'.TEMPLATE.'/settings/item-layout.json';
				$layout = file_get_contents($item_layout);
			}
			
			$layout = json_decode($layout,true); 
			return $layout;
		}
		
		
		public static function get_lightbox_elements() {
			$elements = JPATH_BASE.'/../templates/'.TEMPLATE.'/settings/lightbox-elements.json';
			$elements = file_get_contents($elements);
			$elements = json_decode($elements,true); 
			return $elements;
		}
	
		
		public static function get_galleries($type, $templateId) {
			$gallery_details =  JPATH_BASE.'/templates/'.TEMPLATE.'/settings/gallery-order-'. $templateId .'.json';
			
			if(file_exists($gallery_details)) {
				$details = file_get_contents($gallery_details);
				$details = json_decode($details, $type); 
				return $details;
			}
			else {
				return null;
			}
			
		}
		
		public static function get_user() {
		
			$user = JFactory::getUser();
			
			if (!$user->guest) {
			   $access = 1;
			} else {
			   $access = 0;
			}
			
			return $access;
		}
		
		
		public static function getThemeSettings($param) {
			$settings = explode('|', $param);
			return $settings;
		}
			
			
		public static function isPrivate($id,$templateId) {
			
			$details = self::get_galleries('true',$templateId);
			
			$private = array_key_exists('private', $details) ? $details[$id]['private'] : null;
			
			return $private;
		}
		
		
		public static function isFeatured($id,$templateId) {
			
			$details = self::get_galleries('true',$templateId);
			
			if($details) {
				$featured = array_key_exists('featured', $details)? $details[$id]['featured'] : null;
				return $featured;
			}
			else {
				return;
			}
		}
		
		
		public static function displayGallery($private) {
			
			$access = 1;
			
			if($private) { 
				$access = self::get_user();
			}
			
			return $access;
		}
		
		
		public static function get_featured_pattern($pattern) {
			
			// Create an array where we can count the number of non-featured
			$pattern = explode('1', $pattern);
			return $pattern;
		}
		
		
		public static function create_pattern($pattern) {
			
			$values = self::get_featured_pattern($pattern);
			$pattern = "";
			
			foreach ($values as $key => $value) {
				$value = str_split($value);
				$pattern[]= count($value);
			}
			return $pattern;
		}
	
	
	
		public static function create_photoset_pattern($pattern) {
			
			$values = self::create_pattern($pattern);
			
			$pattern = '';
			
			foreach($values as $key => $value) {
				$pattern .= $value;
				
				if($value!==1) {
					$pattern .= '1';
				}	
			}
			return $pattern;
		}
		
		
		
			
	
		public static function getimages($gallery, $id,  $layout_type, $lightbox, $download_text,$templateId) {
		
			$gallery = self::get_gallery_content($gallery,$templateId);
			
			
			
			if(!empty($gallery)) {
				
				$images = $gallery->images;
				$layout = self::get_layout_details($templateId);
				$details = self::get_galleries('true',$templateId);
				
				$featured = self::isFeatured($id,$templateId);
				$count = (count($layout)-1);
				$layout_type= explode('-', $layout_type);
				$template = $layout_type[0];
			
				
				$featured_pattern = self::create_pattern($gallery->featured_pattern);
				
				if($images !==null) {
			
				 	// Set up the variables to display based on the order set in the template
					foreach ($layout as $key => $item) {
						${$item.$key} = $layout[0];
					} 
					
					$ii = 0;
					
					
					$index = 0;
					$flag=1;
					// Loop through the images and render the output
					foreach($images as $key=>$image) {
						
						
						//echo $index;
						$feature_index = $featured_pattern[$index];
				
						// Get the resized images
						$resized = $image->resized;
						
						if(strpos($resized,'|') !== false)  {
							$resized = explode('|', $resized);
						}
						else{
							$resized = array($image->image,$image->image,$image->image,$image->image,$image->image);
							
						}
						
						
						$image->download = '<p class="download-item"><a title="download '. $image->title .'" class="btn btn-primary btn-download" href="'.JURI::base().$image->image.'" download="'.$image->title.'"><span class="icon-download"></span>'.$download_text.'</a></p>';
						
						if($image->featured || $template == "vertical" || $template == "slideshow" || $template =="largeimages") {
						
							
							if($lightbox) {
								// Set the basic markup for each element
								$image->image = '<div class="zoom-gallery"><p class="image-wrap"><a title="'.$image->title.'" data-desc="'.$image->description.'" data-date="'.$image->date.'" data-author="'.$image->author.'" data-link="'.$image->link.'" data-link-title="'.$image->link_title.'" href="'.JURI::base().$image->image.'"><img class="mfp-img" src="'.$resized[1].'" 
									data-src481="'.JURI::base().$resized[1].'" data-src767="'.JURI::base().$resized[2].'" data-src1025="'.JURI::base().$resized[2].'" data-src1280="'.JURI::base().$resized[3].'" data-src1600="'.JURI::base().$resized[4].'"
									title="'.$image->title.'" alt="'.$image->title.'" /></a></p></div>';
							} else {
								$image->image = '<p class="image-wrap"><img src="'.JURI::base().$resized[1].'" 
									data-src481="'.JURI::base().$resized[1].'" data-src767="'.JURI::base().$resized[2].'" data-src1025="'.JURI::base().$resized[2].'" data-src1280="'.JURI::base().$resized[3].'" data-src1600="'.JURI::base().$resized[4].'"
									title="'.$image->title.'" alt="'.$image->title.'" /></p>';
							}
							
						} else {
							
							if($lightbox) {
								// Set the basic markup for each element
								$image->image = '<div class="zoom-gallery"><p class="image-wrap"><a title="'.$image->title.'" data-desc="'.$image->description.'" data-date="'.$image->date.'" data-author="'.$image->author.'" data-link="'.$image->link.'" data-link-title="'.$image->link_title.'" href="'.JURI::base().$image->image.'"><img class="mfp-img" src="'.$resized[1].'" 
									data-src481="'.JURI::base().$resized[1].'" data-src767="'.JURI::base().$resized[1].'" data-src1025="'.JURI::base().$resized[1].'" data-src1280="'.JURI::base().$resized[1].'" data-src1600="'.JURI::base().$resized[1].'"
									title="'.$image->title.'" alt="'.$image->title.'" /></a></p></div>';
							} else {
								$image->image = '<p class="image-wrap"><img src="'.JURI::base().$resized[1].'" 
									data-src481="'.JURI::base().$resized[1].'" data-src767="'.JURI::base().$resized[1].'" data-src1025="'.JURI::base().$resized[1].'" data-src1280="'.JURI::base().$resized[1].'" data-src1600="'.JURI::base().$resized[1].'"
									title="'.$image->title.'" alt="'.$image->title.'" /></p>';
							}
						}
						
						
						// Null the image download for non featured images in featured layout
						if($template=="featured" && !$image->featured ) {
							
							$image->download = '';
						}
						
						
						$image->title = '<h3 class="gallery-item-title"><span>'.$image->title.'</span></h3>';
						
						if($image->description !=="") {
							$image->description = '<p class="gallery-item-description">'.html_entity_decode($image->description).'</p>';
						}
						
						if($image->date !=="") {
							$image->date = '<p class="gallery-item-date">'.$image->date.'</p>';
						}
						
						if($image->author !=="") {
							$image->author = '<p class="gallery-item-author">'.$image->author.'</p>';
						}					
						
						
						if($image->link !=="") {
							$image->link = '<p class="gallery-item-link"><a class="btn btn-primary" href="'.$image->link.'"><span>'.$image->link_title.'</span></a></p>';
						}
						
										
						// Check if item is featured
						// Store the featired varioable so we can use later
						$featured = $image->featured;
						$itemcount = $key+1;
						
					
						if($template =="featured"){
							
							if(!$featured){
								$image->title = "";
								$image->description = "";
								$image->date = "";
								$image->author = "";
								$image->link = "";
							}
							
							
						
							if(isset($image->featured)) {
								if($image->featured == 1) {
									
									$image->featured = 'gallery-item gallery-item-'.$itemcount.' featured-item';
									
									$index = ($index) + 1;
									
									$flag=1;
								}
								else {
									
									if($flag ==1) {
										$image->featured = 'first-in-row gallery-item gallery-item-'.$itemcount.' col col-'.$feature_index;
										$flag=0;
									}
									else {
										$image->featured = 'gallery-item gallery-item-'.$itemcount.' col col-'.$feature_index;
									}
								
								}
						
							} else {
								
								$image->featured = 'gallery-item gallery-item-'.$itemcount.' col col-'.$feature_index;
							}
							
						} else {
						
							if(isset($image->featured)) {
								if($image->featured == 1) {
									
									$image->featured = 'gallery-item gallery-item-'.$itemcount.' featured-item';
									
									$index = ($index) + 1;
								}
								else {
									$image->featured = 'gallery-item gallery-item-'.$itemcount.'';
								}
							} else {
								$image->featured = 'gallery-item gallery-item-'.$itemcount.'';
							}
							
						}
						
						
						if($template=="grid" || $template=="featured-slideshow") {
							
							if( $ii == ($layout_type[1] % $layout_type[1])) { 
						
								$ii = 0; 
						
								echo '<li class="first-in-row '. $image->featured.'">';
						
							}	
							
							else {
								echo '<li class="'. $image->featured.'">';
							}
						}
						else {
							echo '<li class="'. $image->featured.'">';
						}
						
						// Prevent Featured from outputting 
						$image->featured = '';
						
						
						// Loop through each item andrender the layout
						$i = 0;
						while ($i <= $count) {
							
							echo $image->$layout[$i];
							
							$i++;  
						}
						
						echo '</li>';
						
						$ii++;
						
						if($template=="grid") {
							
							if( $ii == $layout_type[1]) { 
						
								$ii = 0; 
						
								echo '<div class="clearfix"></div>';
						
							}	
						}

					}
				}
			}
			
			else {
				// Gallery Doesnt exist
				echo '<div id="gallery" class="padding"><h1>Gallery not found</h1></div>';
			}
		}
	
		
		
		public static function getfirstimage($templateId) {
		
			$galleries = self::get_galleries(false,$templateId);
			
			if(is_array($galleries)) {
			
				$details = array();
				
				foreach($galleries as $key => $gallery) {
					$details[] = self::get_gallery_images($gallery->name,$templateId);
				}
				
				$firstimages =array();
				
				$details= array_filter($details);
				foreach($details as $key => $image) {
					
					// Needed to revert resized items back to original image if image doesnt exist
					if(isset($image[0])) {
						if(strpos($image[0]->resized,'|') == false)  {
							$image[0]->resized = $image[0]->image.'|'.$image[0]->image.'|'.$image[0]->image.'|'.$image[0]->image.'|'.$image[0]->image;
						}
					}
					
					$firstimages[$key]= array(
							'id' => $galleries[$key]->id,
							'name' =>$galleries[$key]->name,
							'image' =>$image[0]->resized,
							'original' =>$image[0]->image,
							'private'=>$galleries[$key]->private,
							'layout' =>$galleries[$key]->layout,
							'featured'=>$galleries[$key]->featured);
				}
		
				return array_filter($firstimages);
			} else {
				return false;
			}
		}
		
		
		public static function encodeURIComponent($str) {
		    $revert = array('%21'=>'!', '%2A'=>'*', '%27'=>"'", '%28'=>'(', '%29'=>')');
		    return strtr(rawurlencode($str), $revert);
		}
		
		
	}
}